commit: r269 - trunk/daemon

[email protected]
Newsgroups gmane.network.spread.cvs
Message-ID <[email protected]>
Author: jschultz
Date: 2005-08-24 18:10:05 -0400 (Wed, 24 Aug 2005)
New Revision: 269

Modified:
   trunk/daemon/spread.c
   trunk/daemon/spread_params.h
Log:
Yair's changes to spread copyright and initial print statement.



Modified: trunk/daemon/spread.c
===================================================================
--- trunk/daemon/spread_params.h	2005-08-18 04:09:08 UTC (rev 268)
+++ trunk/daemon/spread_params.h	2005-08-24 22:10:05 UTC (rev 269)
@@ -35,9 +35,9 @@
 #ifndef	INC_SPREAD_PARAMS
 #define INC_SPREAD_PARAMS
 
-#define		SP_MAJOR_VERSION	3
-#define         SP_MINOR_VERSION        17
-#define         SP_PATCH_VERSION        3
+#define		SP_MAJOR_VERSION	4
+#define         SP_MINOR_VERSION        0
+#define         SP_PATCH_VERSION        0
 #define         SPREAD_PROTOCOL         3
 
 #define		DEFAULT_SPREAD_PORT	4803
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
--- trunk/daemon/spread.c	2005-08-18 04:09:08 UTC (rev 268)
+++ trunk/daemon/spread.c	2005-08-24 22:10:05 UTC (rev 269)
@@ -18,16 +18,17 @@
  * The Creators of Spread are:
  *  Yair Amir, Michal Miskin-Amir, Jonathan Stanton.
  *
- *  Copyright (C) 1993-2004 Spread Concepts LLC <[email protected]>
+ *  Copyright (C) 1993-2005 Spread Concepts LLC <[email protected]>
  *
  *  All Rights Reserved.
  *
  * Major Contributor(s):
  * ---------------
+ *    Ryan Caudy           [email protected] - contributions to process groups.
  *    Cristina Nita-Rotaru [email protected] - group communication security.
  *    Theo Schlossnagle    [email protected] - Perl, skiplists, autoconf.
  *    Dan Schoenblum       [email protected] - Java interface.
  *    John Schultz         [email protected] - contribution to process group membership.
  *
  */
 
@@ -89,7 +90,7 @@
 
 	Alarmp( SPLOG_PRINT, SYSTEM, "/===========================================================================\\\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| The Spread Toolkit.                                                       |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "| Copyright (c) 1993-2002 Spread Concepts LLC                               |\n"); 
+	Alarmp( SPLOG_PRINT, SYSTEM, "| Copyright (c) 1993-2005 Spread Concepts LLC                               |\n"); 
 	Alarmp( SPLOG_PRINT, SYSTEM, "| All rights reserved.                                                      |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| The Spread toolkit is licensed under the Spread Open-Source License.      |\n");
@@ -103,35 +104,33 @@
 	Alarmp( SPLOG_PRINT, SYSTEM, "| This software is distributed on an \"AS IS\" basis, WITHOUT WARRANTY OF     |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| ANY KIND, either express or implied.                                      |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "| Spread is developed at Spread Concepts LLC and the Center for Networking  |\n");
- 	Alarmp( SPLOG_PRINT, SYSTEM, "| and Distributed Systems, The Johns Hopkins University.                    |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| Creators:                                                                 |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|    Yair Amir             [email protected]                              |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|    Michal Miskin-Amir    [email protected]                        |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|    Jonathan Stanton      [email protected]                                 |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| Major Contributors:                                                       |\n");
+        Alarmp( SPLOG_PRINT, SYSTEM, "|    Ryan Caudy           [email protected] - contribution to process groups.|\n");
         Alarmp( SPLOG_PRINT, SYSTEM, "|    Cristina Nita-Rotaru [email protected] - GC security.                |\n");
-        Alarmp( SPLOG_PRINT, SYSTEM, "|    Theo Schlossnagle    [email protected] - Perl, skiplists, autoconf.     |\n");
+        Alarmp( SPLOG_PRINT, SYSTEM, "|    Theo Schlossnagle    [email protected] - Perl, autoconf, old skiplist.  |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|    Dan Schoenblum       [email protected] - Java interface.             |\n");
-        Alarmp( SPLOG_PRINT, SYSTEM, "|    John Schultz         [email protected] - contribution to process   |\n");
-        Alarmp( SPLOG_PRINT, SYSTEM, "|                                       group membership.                   |\n");
+        Alarmp( SPLOG_PRINT, SYSTEM, "|    John Schultz         jschultz@spreadconcepts - Vitrual Synchrony,      |\n");
+        Alarmp( SPLOG_PRINT, SYSTEM, "|                                       data structures.                    |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| Special thanks to the following for providing ideas and/or code:          |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "|    Ken Birman, Danny Dolev, Mike Goodrich, Ben Laurie,                    |\n");
+	Alarmp( SPLOG_PRINT, SYSTEM, "|    Ken Birman, Danny Dolev, Jacob Green, Mike Goodrich, Ben Laurie,       |\n");
         Alarmp( SPLOG_PRINT, SYSTEM, "|    David Shaw, Robbert VanRenesse.                                        |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
         Alarmp( SPLOG_PRINT, SYSTEM, "| Partial funding provided by the Defense Advanced Research Project Agency  |\n");
-        Alarmp( SPLOG_PRINT, SYSTEM, "| (DARPA) and the National Security Agency (NSA) since 2000. The Spread     |\n");
+        Alarmp( SPLOG_PRINT, SYSTEM, "| (DARPA) and the National Security Agency (NSA) 2000-2004. The Spread      |\n");
         Alarmp( SPLOG_PRINT, SYSTEM, "| toolkit is not necessarily endorsed by DARPA or the NSA.                  |\n");
         Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "| For a full list of contributors, see Readme.txt in the distribution.      |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "| WWW:     www.spread.org     www.cnds.jhu.edu    www.spreadconcepts.com    |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "| Contact: [email protected]                                                |\n");
+	Alarmp( SPLOG_PRINT, SYSTEM, "| WWW:     www.spread.org     www.spreadconcepts.com                        |\n");
+	Alarmp( SPLOG_PRINT, SYSTEM, "| Contact: [email protected]                                          |\n");
 	Alarmp( SPLOG_PRINT, SYSTEM, "|                                                                           |\n");
-	Alarmp( SPLOG_PRINT, SYSTEM, "| Version %d.%02d.%02d Built 15/October/2004                                     |\n", 
+	Alarmp( SPLOG_PRINT, SYSTEM, "| Version %d.%02d.%02d Built 24/August/2005                                      |\n", 
 		(int)SP_MAJOR_VERSION, (int)SP_MINOR_VERSION, (int)SP_PATCH_VERSION );
 	Alarmp( SPLOG_PRINT, SYSTEM, "\\===========================================================================/\n");
 
@@ -18,16 +18,17 @@
  *    Cristina Nita-Rotaru [email protected] - group communication security.
- *    Theo Schlossnagle    [email protected] - Perl, skiplists, autoconf.
+ *    Theo Schlossnagle    [email protected] - Perl, autoconf, old skiplist.
  *    Dan Schoenblum       [email protected] - Java interface.
@@ -18,16 +18,17 @@
  *    Dan Schoenblum       [email protected] - Java interface.
- *    John Schultz         [email protected] - contribution to process group membership.
+ *    John Schultz         [email protected] - Virtual Synchrony, data structures.
  *
  */

Modified: trunk/daemon/spread_params.h
===================================================================